pub struct ModuleLearningRate { /* private fields */ }Available on crate feature
std only.Expand description
Determines what learning rate to use for a given trainable parameter.
Implementations
Sourceimpl ModuleLearningRate
impl ModuleLearningRate
Sourcepub fn lr_from_param(&self, id: ParamId, path: Option<&str>) -> LearningRate
pub fn lr_from_param(&self, id: ParamId, path: Option<&str>) -> LearningRate
Get the effective learning rate for the given parameter.
Sourcepub fn base(&self) -> LearningRate
pub fn base(&self) -> LearningRate
Get the base learning rate value which’s group matches all parameters.