burn-optim 0.19.0

Optimizer building blocks for the Burn deep learning framework
docs.rs failed to build burn-optim-0.19.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: burn-optim-0.21.0-pre.5

Burn Optimizers

Core building blocks for Burn optimizers.