pub struct AdanConfig { /* private fields */ }Expand description
Adan Configuration.
See:
Implementations
Sourceimpl AdanConfig
impl AdanConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new instance of the config.
Arguments
Optional Arguments
grad_clipping
Gradient Clipping config.
- Defaults to
None
Default Arguments
beta_1
Parameter for the first moment.
- Defaults to
0.98
beta_2
Parameter for the gradient-difference momentum.
- Defaults to
0.92
beta_3
Parameter for the second moment.
- Defaults to
0.99
epsilon
A value required for numerical stability.
- Defaults to
1e-8
weight_decay
Weight decay factor.
- Defaults to
0.0
no_prox
Disable proximal weight decay and use the decoupled update instead.
- Defaults to
false
Sourceimpl AdanConfig
impl AdanConfig
Sourcepub fn with_beta_1(self, beta_1: f32) -> Self
pub fn with_beta_1(self, beta_1: f32) -> Self
Sourcepub fn with_beta_2(self, beta_2: f32) -> Self
pub fn with_beta_2(self, beta_2: f32) -> Self
Sets the value for the field beta_2.
Parameter for the gradient-difference momentum.
- Defaults to
0.92
Sourcepub fn with_beta_3(self, beta_3: f32) -> Self
pub fn with_beta_3(self, beta_3: f32) -> Self
Sourcepub fn with_epsilon(self, epsilon: f32) -> Self
pub fn with_epsilon(self, epsilon: f32) -> Self
Sourcepub fn with_weight_decay(self, weight_decay: f32) -> Self
pub fn with_weight_decay(self, weight_decay: f32) -> Self
Sourcepub fn with_no_prox(self, no_prox: bool) -> Self
pub fn with_no_prox(self, no_prox: bool) -> Self
Sets the value for the field no_prox.
Disable proximal weight decay and use the decoupled update instead.
- Defaults to
false
Sourcepub fn with_grad_clipping(
self,
grad_clipping: Option<GradientClippingConfig>,
) -> Self
pub fn with_grad_clipping( self, grad_clipping: Option<GradientClippingConfig>, ) -> Self
Sourceimpl AdanConfig
impl AdanConfig
Sourcepub fn init<B: AutodiffBackend, M: AutodiffModule<B>>(
&self,
) -> OptimizerAdaptor<Adan, M, B>
pub fn init<B: AutodiffBackend, M: AutodiffModule<B>>( &self, ) -> OptimizerAdaptor<Adan, M, B>