pub struct CenteredState<const D: usize> {
pub grad_avg: Option<Tensor<D>>,
pub avg: Tensor<D>,
}Expand description
CenteredState is to store and pass optimizer step params.
Fields
grad_avg: Option<Tensor<D>>The averaged gradient to calculate the centered gradient, if available.
avg: Tensor<D>The current average value.
Implementations
Sourceimpl<const D: usize> CenteredState<D>
impl<const D: usize> CenteredState<D>