pub struct GradientsAccumulator<M> { /* private fields */ }Expand description
Accumulate gradients into a single GradientsParams object.
Implementations
Sourceimpl<M> GradientsAccumulator<M>
impl<M> GradientsAccumulator<M>
Sourceimpl<M> GradientsAccumulator<M>
impl<M> GradientsAccumulator<M>
Sourcepub fn accumulate(&mut self, module: &M, grads: GradientsParams)where
M: AutodiffModule,
pub fn accumulate(&mut self, module: &M, grads: GradientsParams)where
M: AutodiffModule,
Accumulate the given gradients for each parameter in the given module.
Sourcepub fn grads(&mut self) -> GradientsParams
pub fn grads(&mut self) -> GradientsParams
Return the accumulated gradients and reset the accumulator state.