pub struct GradientsParams { /* private fields */ }Expand description
Data type that contains gradients for parameters.
Implementations
Sourceimpl GradientsParams
impl GradientsParams
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new GradientsParams.
Sourcepub fn from_grads<M: AutodiffModule>(grads: Gradients, module: &M) -> Self
pub fn from_grads<M: AutodiffModule>(grads: Gradients, module: &M) -> Self
Extract each tensor gradients for the given module.
Note: This consumes the gradients. See [‘from_module’] to extract gradients only for a specific module.
Sourcepub fn from_module<M: AutodiffModule>(grads: &mut Gradients, module: &M) -> Self
pub fn from_module<M: AutodiffModule>(grads: &mut Gradients, module: &M) -> Self
Extract each tensor gradients for the given module.
Sourcepub fn from_params<M: AutodiffModule>(
grads: &mut Gradients,
module: &M,
params: &[ParamId],
) -> Self
pub fn from_params<M: AutodiffModule>( grads: &mut Gradients, module: &M, params: &[ParamId], ) -> Self
Extract tensor gradients for the given module and given parameters.
Sourcepub fn get<const D: usize>(&self, id: ParamId) -> Option<Tensor<D>>
pub fn get<const D: usize>(&self, id: ParamId) -> Option<Tensor<D>>
Get the gradients for the given parameter id.
Notes
You should use remove if you want to get the gradients only one time.
Sourcepub fn remove<const D: usize>(&mut self, id: ParamId) -> Option<Tensor<D>>
pub fn remove<const D: usize>(&mut self, id: ParamId) -> Option<Tensor<D>>
Remove the gradients for the given parameter id.
Sourcepub fn register<const D: usize>(&mut self, id: ParamId, value: Tensor<D>)
pub fn register<const D: usize>(&mut self, id: ParamId, value: Tensor<D>)
Register a gradients tensor for the given parameter id.
Notes
If a tensor is already registered for the given parameter id, it will be replaced.