pub struct Lamb { /* private fields */ }Expand description
Layer-wise Adaptive Moments (LAMB) optimizer.
LAMB applies an Adam-style update, then scales it by the ratio between the parameter norm and update norm. This layer-wise adaptation is useful when training with very large batch sizes.
See: Large Batch Optimization for Deep Learning: Training BERT in 76 minutes.
Configured by LambConfig.