pub struct LambConfig { /* private fields */ }Expand description
Lamb configuration.
Implementations
Sourceimpl LambConfig
impl LambConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new instance of the config.
Arguments
Optional Arguments
grad_clipping
Optional gradient clipping configuration.
- Defaults to
None
Default Arguments
beta_1
Exponential decay rate for the first moment estimates.
- Defaults to
0.9
beta_2
Exponential decay rate for the second moment estimates.
- Defaults to
0.999
epsilon
A value added to the denominator for numerical stability.
- Defaults to
1e-6
weight_decay
Weight decay applied to the Adam update before layer-wise adaptation.
- Defaults to
0.0
use_trust_ratio
Whether to scale each parameter update by its layer-wise trust ratio.
- Defaults to
true
Sourceimpl LambConfig
impl LambConfig
Sourcepub fn with_beta_1(self, beta_1: f32) -> Self
pub fn with_beta_1(self, beta_1: f32) -> Self
Sets the value for the field beta_1.
Exponential decay rate for the first moment estimates.
- Defaults to
0.9
Sourcepub fn with_beta_2(self, beta_2: f32) -> Self
pub fn with_beta_2(self, beta_2: f32) -> Self
Sets the value for the field beta_2.
Exponential decay rate for the second moment estimates.
- Defaults to
0.999
Sourcepub fn with_epsilon(self, epsilon: f32) -> Self
pub fn with_epsilon(self, epsilon: f32) -> Self
Sets the value for the field epsilon.
A value added to the denominator for numerical stability.
- Defaults to
1e-6
Sourcepub fn with_weight_decay(self, weight_decay: f32) -> Self
pub fn with_weight_decay(self, weight_decay: f32) -> Self
Sets the value for the field weight_decay.
Weight decay applied to the Adam update before layer-wise adaptation.
- Defaults to
0.0
Sourcepub fn with_use_trust_ratio(self, use_trust_ratio: bool) -> Self
pub fn with_use_trust_ratio(self, use_trust_ratio: bool) -> Self
Sets the value for the field use_trust_ratio.
Whether to scale each parameter update by its layer-wise trust ratio.
- Defaults to
true
Sourcepub fn with_grad_clipping(
self,
grad_clipping: Option<GradientClippingConfig>,
) -> Self
pub fn with_grad_clipping( self, grad_clipping: Option<GradientClippingConfig>, ) -> Self
Sets the value for the field grad_clipping.
Optional gradient clipping configuration.
- Defaults to
None
Sourceimpl LambConfig
impl LambConfig
Sourcepub fn build(&self) -> Lamb
pub fn build(&self) -> Lamb
Build the per-parameter LAMB optimizer.
Use Self::init to construct a whole-module optimizer with the configured gradient
clipping behavior.
Sourcepub fn init(&self) -> ModuleOptimizer
pub fn init(&self) -> ModuleOptimizer
Initialize a whole-module LAMB optimizer.