pub struct RmsPropConfig { /* private fields */ }Expand description
Configuration to create the RmsProp optimizer.
Implementations
Sourceimpl RmsPropConfig
impl RmsPropConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new instance of the config.
Arguments
Optional Arguments
weight_decay
Weight decay config.
- Defaults to
None
grad_clipping
Gradient Clipping config.
- Defaults to
None
Default Arguments
alpha
Smoothing constant.
- Defaults to
0.99
momentum
momentum for RmsProp.
- Defaults to
0.9
epsilon
A value required for numerical stability.
- Defaults to
1e-5
centered
if True, compute the centered RmsProp, the gradient is normalized by an estimation of its variance
- Defaults to
false
Sourceimpl RmsPropConfig
impl RmsPropConfig
Sourcepub fn with_alpha(self, alpha: f32) -> Self
pub fn with_alpha(self, alpha: f32) -> Self
Sourcepub fn with_momentum(self, momentum: f32) -> Self
pub fn with_momentum(self, momentum: f32) -> Self
Sourcepub fn with_epsilon(self, epsilon: f32) -> Self
pub fn with_epsilon(self, epsilon: f32) -> Self
Sourcepub fn with_centered(self, centered: bool) -> Self
pub fn with_centered(self, centered: bool) -> Self
Sets the value for the field centered.
if True, compute the centered RmsProp, the gradient is normalized by an estimation of its variance
- Defaults to
false
Sourcepub fn with_weight_decay(self, weight_decay: Option<WeightDecayConfig>) -> Self
pub fn with_weight_decay(self, weight_decay: Option<WeightDecayConfig>) -> Self
Sourcepub fn with_grad_clipping(
self,
grad_clipping: Option<GradientClippingConfig>,
) -> Self
pub fn with_grad_clipping( self, grad_clipping: Option<GradientClippingConfig>, ) -> Self
Sourceimpl RmsPropConfig
impl RmsPropConfig
Sourcepub fn build(&self) -> RmsProp
pub fn build(&self) -> RmsProp
Build a RmsProp from the config.
The bare optimizer, which
ModuleOptimizer::with_group takes to
optimize one parameter group. init is the whole-module
counterpart, and the only one that applies the configured gradient clipping.
Sourcepub fn init(&self) -> ModuleOptimizer
pub fn init(&self) -> ModuleOptimizer