Burn optimizers.
Modules
- decay
- Weight decay module for optimizers.
- grad_
clipping - Gradient clipping module.
- lr_
scheduler std - Learning rate scheduler module.
- module_
optimizer - Adaptor module for optimizers.
- momentum
- Momentum module for optimizers.
- record
- Record module for optimizers.
Structs
- AdaGrad
- AdaGrad optimizer
- AdaGrad
Config - AdaGrad configuration.
- AdaGrad
State - AdaGrad state.
- Adam
- Adam optimizer.
- Adam
Config - Adam configuration.
- Adam
State - Adam state.
- AdamW
- AdamW optimizer.
- AdamW
Config AdamWConfiguration.- AdamW
State - AdamW state.
- Adan
- Adan optimizer.
- Adan
Config AdanConfiguration.- Adan
State - Adan state.
- Adaptive
Momentum State - Adaptive momentum state.
- Adaptive
Nesterov Momentum State - Adaptive Nesterov momentum state.
- Centered
State - CenteredState is to store and pass optimizer step params.
- DynState
- A type-erased optimizer state for a single parameter.
- Gradients
Accumulator - Accumulate gradients into a single GradientsParams object.
- Gradients
Params - Data type that contains gradients for parameters.
- LBFGS
- L-BFGS optimizer.
- LBFGS
Config - LBFGS Configuration.
- LBFGS
State - L-BFGS optimizer state
- LrDecay
State - Learning rate decay state (also includes sum state).
- Module
Optimizer - Optimizes a whole module by applying a per-parameter
Optimizerto each of its parameters. - Multi
Gradients Params - Exposes multiple gradients for each parameter.
- Muon
- Muon optimizer.
- Muon
Config - Muon configuration.
- Muon
State - Muon state.
- Optimizer
Record - A serialized optimizer state, stored in the burnpack format.
- RmsProp
- Optimizer that implements stochastic gradient descent with momentum. The optimizer can be configured with RmsPropConfig.
- RmsProp
Config - Configuration to create the RmsProp optimizer.
- RmsProp
Momentum - RmsPropMomentum is to store config status for optimizer.
(, which is stored in optimizer itself and not passed in during
step()calculation) - RmsProp
Momentum State - RmsPropMomentumState is to store and pass optimizer step params.
- RmsProp
State - State of RmsProp
- Sgd
- Optimizer that implements stochastic gradient descent with momentum.
- SgdConfig
- Configuration to create the Sgd optimizer.
- SgdState
- State of Sgd.
- Square
AvgState - SquareAvgState is to store and pass optimizer step params.
- State
Sink - Accumulates the named tensors and scalars produced while flattening a
RecordState. - State
Source - Provides the named tensors and scalars consumed while reconstructing an
RecordState.
Enums
- Adjust
LrFn - Learning rate adjustment method for Muon optimizer.
- Grad
Adaptor - Wrapper to unify the
removemethod for GradientsParams and MultiGradientsParams. - Line
Search Fn - Strategy for the line search optimization phase
Traits
- DynOptimizer
- Object-safe view over an
Optimizer, allowingModuleOptimizerto stay non-generic. Rank-generic operations are dispatched on a runtime rank. - Optimizer
- An opinionated trait to simplify the process of implementing an optimizer.
- Record
State - A type that can be flattened into named tensors and scalars and rebuilt from them.
Functions
- join_
index - Join a
prefixand a numericindexinto a dot-separated path ("prefix.3"). - join_
path - Join a
prefixand aleafinto a dot-separated path ("prefix.leaf").
Type Aliases
- Learning
Rate - Type alias for the learning rate.
Derive Macros
- Record
State - Derive macro for a recordable state (optimizer or learning-rate scheduler), decomposing it into named tensors and scalars for the burnpack format.