Crate burn_optim

Crate burn_optim 

Burn optimizers.

Modules

adaptor
Adaptor module for optimizers.
decay
Weight decay module for optimizers.
grad_clipping
Gradient clipping module.
lr_schedulerstd
Learning rate scheduler module.
momentum
Momentum module for optimizers.
record
Record module for optimizers.

Structs

AdaGrad
AdaGrad optimizer
AdaGradConfig
AdaGrad configuration.
AdaGradState
AdaGrad state.
AdaGradStateItem
The record item type for the module.
Adam
Adam optimizer.
AdamConfig
Adam configuration.
AdamState
Adam state.
AdamStateItem
The record item type for the module.
AdamW
AdamW optimizer.
AdamWConfig
AdamW Configuration.
AdamWState
AdamW state.
AdamWStateItem
The record item type for the module.
Adan
Adan optimizer.
AdanConfig
Adan Configuration.
AdanState
Adan state.
AdanStateItem
The record item type for the module.
AdaptiveMomentumState
Adaptive momentum state.
AdaptiveMomentumStateItem
The record item type for the module.
AdaptiveNesterovMomentumState
Adaptive Nesterov momentum state.
AdaptiveNesterovMomentumStateItem
The record item type for the module.
CenteredState
CenteredState is to store and pass optimizer step params.
CenteredStateItem
The record item type for the module.
GradientsAccumulator
Accumulate gradients into a single Gradients object.
GradientsParams
Data type that contains gradients for parameters.
LBFGS
L-BFGS optimizer.
LBFGSConfig
LBFGS Configuration.
LBFGSState
L-BFGS optimizer state
LBFGSStateItem
The record item type for the module.
LrDecayState
Learning rate decay state (also includes sum state).
LrDecayStateItem
The record item type for the module.
MultiGradientsParams
Exposes multiple gradients for each parameter.
Muon
Muon optimizer.
MuonConfig
Muon configuration.
MuonState
Muon state.
MuonStateItem
The record item type for the module.
RmsProp
Optimizer that implements stochastic gradient descent with momentum. The optimizer can be configured with RmsPropConfig.
RmsPropConfig
Configuration to create the RmsProp optimizer.
RmsPropMomentum
RmsPropMomentum is to store config status for optimizer. (, which is stored in optimizer itself and not passed in during step() calculation)
RmsPropMomentumState
RmsPropMomentumState is to store and pass optimizer step params.
RmsPropMomentumStateItem
The record item type for the module.
RmsPropState
State of RmsProp
RmsPropStateItem
The record item type for the module.
Sgd
Optimizer that implements stochastic gradient descent with momentum.
SgdConfig
Configuration to create the Sgd optimizer.
SgdState
State of Sgd.
SgdStateItem
The record item type for the module.
SquareAvgState
SquareAvgState is to store and pass optimizer step params.
SquareAvgStateItem
The record item type for the module.

Enums

AdjustLrFn
Learning rate adjustment method for Muon optimizer.
LineSearchFn
Strategy for the line search optimization phase

Traits

Optimizer
General trait to optimize module.
SimpleOptimizer
Simple optimizer is an opinionated trait to simplify the process of implementing an optimizer.

Type Aliases

LearningRate
Type alias for the learning rate.